<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.System.Power

Windows Runtime (WinRT) APIs for for the `Windows.Phone.System.Power` namespace.

This package provides the `winrt.windows.phone.system.power` module.
